@@ -1583,6 +1583,10 @@ func TestFetchJWTSVID(t *testing.T) {
 	require.Error(t, err)
 	require.Empty(t, svid)
 
+	testEntry := regEntriesMap["resp2"][0]
+	testEntrySPIFFEId, err := idutil.IDProtoFromString(testEntry.SpiffeId)
+	require.NoError(t, err)
+
 	now := clk.Now()
 	// fetch succeeds
 	tokenA := "A"
@@ -1590,10 +1594,11 @@ func TestFetchJWTSVID(t *testing.T) {
 	expiresAtA := now.Add(time.Minute).Unix()
 	fetchResp.Svid = &types.JWTSVID{
 		Token:     tokenA,
+		Id:        testEntrySPIFFEId,
 		IssuedAt:  issuedAtA,
 		ExpiresAt: expiresAtA,
 	}
-	svid, err = m.FetchJWTSVID(context.Background(), regEntriesMap["resp2"][0], audience)
+	svid, err = m.FetchJWTSVID(context.Background(), testEntry, audience)
 	require.NoError(t, err)
 	require.Equal(t, tokenA, svid.Token)
 	require.Equal(t, issuedAtA, svid.IssuedAt.Unix())
@@ -1602,10 +1607,11 @@ func TestFetchJWTSVID(t *testing.T) {
 	// assert cached JWT is returned w/o trying to fetch (since cached version does not expire soon)
 	fetchResp.Svid = &types.JWTSVID{
 		Token:     "B",
+		Id:        testEntrySPIFFEId,
 		IssuedAt:  now.Unix(),
 		ExpiresAt: now.Add(time.Minute).Unix(),
 	}
-	svid, err = m.FetchJWTSVID(context.Background(), regEntriesMap["resp2"][0], audience)
+	svid, err = m.FetchJWTSVID(context.Background(), testEntry, audience)
 	require.NoError(t, err)
 	require.Equal(t, tokenA, svid.Token)
 	require.Equal(t, issuedAtA, svid.IssuedAt.Unix())
@@ -1619,10 +1625,11 @@ func TestFetchJWTSVID(t *testing.T) {
 	expiresAtC := now.Add(time.Minute).Unix()
 	fetchResp.Svid = &types.JWTSVID{
 		Token:     tokenC,
+		Id:        testEntrySPIFFEId,
 		IssuedAt:  issuedAtC,
 		ExpiresAt: expiresAtC,
 	}
-	svid, err = m.FetchJWTSVID(context.Background(), regEntriesMap["resp2"][0], audience)
+	svid, err = m.FetchJWTSVID(context.Background(), testEntry, audience)
 	require.NoError(t, err)
 	require.Equal(t, tokenC, svid.Token)
 	require.Equal(t, issuedAtC, svid.IssuedAt.Unix())
@@ -1631,7 +1638,7 @@ func TestFetchJWTSVID(t *testing.T) {
 	// expire the JWT soon, fail the fetch, and make sure cached JWT is returned
 	clk.Add(time.Second * 30)
 	fetchResp.Svid = nil
-	svid, err = m.FetchJWTSVID(context.Background(), regEntriesMap["resp2"][0], audience)
+	svid, err = m.FetchJWTSVID(context.Background(), testEntry, audience)
 	require.NoError(t, err)
 	require.Equal(t, tokenC, svid.Token)
 	require.Equal(t, issuedAtC, svid.IssuedAt.Unix())
@@ -1640,7 +1647,7 @@ func TestFetchJWTSVID(t *testing.T) {
 	// now completely expire the JWT and make sure an error is returned, since
 	// the fetch fails and the cached version is expired.
 	clk.Add(time.Second * 30)
-	svid, err = m.FetchJWTSVID(context.Background(), regEntriesMap["resp2"][0], audience)
+	svid, err = m.FetchJWTSVID(context.Background(), testEntry, audience)
 	require.Error(t, err)
 	require.Nil(t, svid)
 }
