@@ -24,10 +24,11 @@ import (
 )
 
 const (
-	pluginName         = "docker"
-	subselectorLabel   = "label"
-	subselectorImageID = "image_id"
-	subselectorEnv     = "env"
+	pluginName                   = "docker"
+	subselectorLabel             = "label"
+	subselectorImageID           = "image_id"
+	subselectorEnv               = "env"
+	subselectorImageConfigDigest = "image_config_digest"
 )
 
 func BuiltIn() catalog.BuiltIn {
@@ -151,11 +152,21 @@ func (p *Plugin) Attest(ctx context.Context, req *workloadattestorv1.AttestReque
 
 	selectors := getSelectorValuesFromConfig(container.Config)
 
+	var imageJSON image.InspectResponse
+	var inspectErr error
+	imageName := container.Config.Image
+	if imageName != "" || p.sigstoreVerifier != nil {
+		imageJSON, _, inspectErr = p.docker.ImageInspectWithRaw(ctx, imageName)
+	}
+
+	// Add image_config_digest selector
+	if inspectErr == nil && imageJSON.ID != "" {
+		selectors = append(selectors, fmt.Sprintf("%s:%s", subselectorImageConfigDigest, imageJSON.ID))
+	}
+
 	if p.sigstoreVerifier != nil {
-		imageName := container.Config.Image
-		imageJSON, _, err := p.docker.ImageInspectWithRaw(ctx, imageName)
-		if err != nil {
-			return nil, fmt.Errorf("failed to inspect image %q: %w", imageName, err)
+		if inspectErr != nil {
+			return nil, fmt.Errorf("failed to inspect image %q: %w", imageName, inspectErr)
 		}
 
 		if len(imageJSON.RepoDigests) == 0 {
