@@ -24,11 +24,16 @@ func TestKeyTypeFromString(t *testing.T) {
 			keyType:       "ec-p256",
 			expectKeyType: workloadkey.ECP256,
 		},
+		{
+			name:          "EC 384",
+			keyType:       "ec-p384",
+			expectKeyType: workloadkey.ECP384,
+		},
 		{
 			name:          "unsupported type",
 			keyType:       "Unsupported",
 			expectKeyType: workloadkey.KeyTypeUnset,
-			errMsg:        "key type \"Unsupported\" is unknown; must be one of [rsa-2048, ec-p256]",
+			errMsg:        "key type \"Unsupported\" is unknown; must be one of [rsa-2048, ec-p256, ec-p384]",
 		},
 	} {
 		t.Run(tt.name, func(t *testing.T) {
