@@ -76,7 +76,6 @@ func (s *TokenSuite) TestDifferentKeys() {
 	}
 
 	for _, testCase := range testCases {
-		testCase := testCase // alias loop variable as it is used in the closure
 		s.T().Run(testCase.kid, func(t *testing.T) {
 			token := s.signJWTSVID(fakeSpiffeID, fakeAudience, time.Now().Add(time.Hour), testCase.key, testCase.kid)
 
@@ -102,7 +101,7 @@ func (s *TokenSuite) TestValidateBadAlgorithm() {
 	token := s.signToken(jose.HS256, key, jwt.Claims{})
 
 	spiffeID, claims, err := ValidateToken(ctx, token, s.bundle, fakeAudience[0:1])
-	s.Require().EqualError(err, `unable to parse JWT token: go-jose/go-jose: unexpected signature algorithm "HS256"; expected ["ES256" "ES384" "ES512" "RS256" "RS384" "RS512" "PS256" "PS384" "PS512"]`)
+	s.Require().EqualError(err, `unable to parse JWT token: unexpected signature algorithm "HS256"; expected ["ES256" "ES384" "ES512" "RS256" "RS384" "RS512" "PS256" "PS384" "PS512"]`)
 	s.Require().Empty(spiffeID)
 	s.Require().Nil(claims)
 }
@@ -136,10 +135,20 @@ func (s *TokenSuite) TestValidateNoSubject() {
 	s.Require().Nil(claims)
 }
 
+func (s *TokenSuite) TestValidateNoExpiry() {
+	token := s.signJWTSVID(fakeSpiffeID, fakeAudience, time.Time{}, ec256Key, "ec256Key")
+
+	spiffeID, claims, err := ValidateToken(ctx, token, s.bundle, fakeAudience[0:1])
+	s.Require().EqualError(err, "token missing exp claim")
+	s.Require().Empty(spiffeID)
+	s.Require().Nil(claims)
+}
+
 func (s *TokenSuite) TestValidateSubjectNotForDomain() {
 	token := s.signToken(jose.ES256, jose.JSONWebKey{Key: ec256Key, KeyID: "ec256Key"}, jwt.Claims{
 		Subject:  "spiffe://other.org/foo",
 		Audience: []string{"audience"},
+		Expiry:   jwt.NewNumericDate(time.Now().Add(time.Hour)),
 	})
 
 	spiffeID, claims, err := ValidateToken(ctx, token, s.bundle, []string{"FOO"})
@@ -151,6 +160,7 @@ func (s *TokenSuite) TestValidateSubjectNotForDomain() {
 func (s *TokenSuite) TestValidateNoAudience() {
 	token := s.signToken(jose.ES256, jose.JSONWebKey{Key: ec256Key, KeyID: "ec256Key"}, jwt.Claims{
 		Subject: fakeSpiffeID.String(),
+		Expiry:  jwt.NewNumericDate(time.Now().Add(time.Hour)),
 	})
 
 	spiffeID, claims, err := ValidateToken(ctx, token, s.bundle, []string{"FOO"})
@@ -202,11 +212,14 @@ func (s *TokenSuite) signToken(alg jose.SignatureAlgorithm, key any, claims jwt.
 func (s *TokenSuite) signJWTSVID(id spiffeid.ID, audience []string, expires time.Time, signer crypto.Signer, kid string) string {
 	claims := jwt.Claims{
 		Subject:  id.String(),
-		Expiry:   jwt.NewNumericDate(expires),
 		Audience: audience,
 		IssuedAt: jwt.NewNumericDate(s.clock.Now()),
 	}
 
+	if !expires.IsZero() {
+		claims.Expiry = jwt.NewNumericDate(expires)
+	}
+
 	alg, err := cryptoutil.JoseAlgFromPublicKey(signer.Public())
 	s.Require().NoError(err)
 
