@@ -2,6 +2,7 @@ package log
 
 import (
 	"fmt"
+	"io"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -46,6 +47,13 @@ func WithOutputFile(file string) Option {
 	}
 }
 
+func WithOutputWriter(w io.Writer) Option {
+	return func(logger *Logger) error {
+		logger.SetOutput(w)
+		return nil
+	}
+}
+
 // WithReopenableOutputFile uses ReopenableFile to support handling a signal
 // to rotate log files (e.g. from a logrotate postrotate script).
 func WithReopenableOutputFile(reopenableFile *ReopenableFile) Option {
