@@ -22,7 +22,7 @@ var (
 func MakeAllTrueMask(m proto.Message) proto.Message {
 	v := reflect.ValueOf(proto.Clone(m)).Elem()
 	t := v.Type()
-	for i := 0; i < v.NumField(); i++ {
+	for i := range v.NumField() {
 		ft := t.Field(i)
 		fv := v.Field(i)
 		// Skip the protobuf internal fields or those that aren't bools
