@@ -1,6 +1,7 @@
 package util
 
 import (
+	"crypto/x509"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -13,9 +14,9 @@ func TestLoadCertPool(t *testing.T) {
 	_, err := LoadCertPool("testdata/empty-bundle.pem")
 	require.EqualError(err, "no certificates found in file")
 
-	// expect two certificates from mixed bundle. the key in the bundle should
+	// expect >0 certificates from mixed bundle. the key in the bundle should
 	// be ignored.
 	pool, err := LoadCertPool("testdata/mixed-bundle.pem")
 	require.NoError(err)
-	require.Len(pool.Subjects(), 2)
+	require.False(pool.Equal(x509.NewCertPool()))
 }
