@@ -94,6 +94,7 @@ func (s *CATestSuite) SetupTest() {
 	})
 	s.setX509CA(true)
 	s.setJWTKey()
+	s.setWITKey()
 }
 
 func (s *CATestSuite) TestDisableJWTSVIDs() {
@@ -107,6 +108,17 @@ func (s *CATestSuite) TestDisableJWTSVIDs() {
 	s.True(ca.IsJWTSVIDsDisabled(), "DisableJWTSVIDs not changed to true")
 }
 
+func (s *CATestSuite) TestDisableWITSVIDs() {
+	s.False(s.ca.IsWITSVIDsDisabled(), "DisableWITSVIDs should be false by default")
+
+	ca := NewCA(Config{
+		TrustDomain:     trustDomainExample,
+		HealthChecker:   s.healthChecker,
+		DisableWITSVIDs: true,
+	})
+	s.True(ca.IsWITSVIDsDisabled(), "DisableWITSVIDs not changed to true")
+}
+
 func (s *CATestSuite) TestSignServerX509SVIDNoCASet() {
 	s.ca.SetX509CA(nil)
 	_, err := s.ca.SignServerX509SVID(ctx, s.createServerX509SVIDParams())
@@ -588,6 +600,14 @@ func (s *CATestSuite) setJWTKey() {
 	})
 }
 
+func (s *CATestSuite) setWITKey() {
+	s.ca.SetWITKey(&WITKey{
+		Signer:   testSigner,
+		Kid:      "KID",
+		NotAfter: s.clock.Now().Add(10 * time.Minute),
+	})
+}
+
 func (s *CATestSuite) createServerX509SVIDParams() ServerX509SVIDParams {
 	return ServerX509SVIDParams{
 		PublicKey: testSigner.Public(),
