@@ -66,9 +66,11 @@ func TestInitialize(t *testing.T) {
 		hasNext          bool
 		prepareJWTKeyErr error
 		prepareX509CAErr error
+		prepareWITKeyErr error
 
 		expectCurrentX509CAID string
 		expectCurrentJWTKeyID string
+		expectCurrentWITKeyID string
 		moveToPrepare         bool
 		moveToActivate        bool
 	}{
@@ -77,6 +79,7 @@ func TestInitialize(t *testing.T) {
 			hasCurrent:            true,
 			expectCurrentJWTKeyID: "jwt-a",
 			expectCurrentX509CAID: "x509-a",
+			expectCurrentWITKeyID: "wit-a",
 		},
 		{
 			name:             "failed to prepare current X509CA",
@@ -89,20 +92,22 @@ func TestInitialize(t *testing.T) {
 			prepareJWTKeyErr: errors.New("oh no"),
 		},
 		{
-			name:                  "prepare and activate current when does not exist",
-			expectCurrentJWTKeyID: "jwt-a",
-			expectCurrentX509CAID: "x509-a",
+			name:             "failed to prepare current WIT Key",
+			expectError:      "oh no",
+			prepareWITKeyErr: errors.New("oh no"),
 		},
 		{
 			name:                  "prepare and activate current when does not exist",
 			expectCurrentJWTKeyID: "jwt-a",
 			expectCurrentX509CAID: "x509-a",
+			expectCurrentWITKeyID: "wit-a",
 		},
 		{
 			name:                  "prepare next",
 			hasCurrent:            true,
 			expectCurrentJWTKeyID: "jwt-a",
 			expectCurrentX509CAID: "x509-a",
+			expectCurrentWITKeyID: "wit-a",
 			moveToPrepare:         true,
 		},
 		{
@@ -119,11 +124,27 @@ func TestInitialize(t *testing.T) {
 			prepareJWTKeyErr: errors.New("oh no"),
 			moveToPrepare:    true,
 		},
+		{
+			name:             "failed to prepare next WIT Key",
+			hasCurrent:       true,
+			expectError:      "oh no",
+			prepareWITKeyErr: errors.New("oh no"),
+			moveToPrepare:    true,
+		},
 		{
 			name:                  "activate next",
 			hasCurrent:            true,
 			expectCurrentJWTKeyID: "jwt-b",
 			expectCurrentX509CAID: "x509-b",
+			expectCurrentWITKeyID: "wit-b",
+			moveToActivate:        true,
+		},
+		{
+			name:                  "activate next",
+			hasCurrent:            true,
+			expectCurrentJWTKeyID: "jwt-b",
+			expectCurrentX509CAID: "x509-b",
+			expectCurrentWITKeyID: "wit-b",
 			moveToActivate:        true,
 		},
 	} {
@@ -133,10 +154,13 @@ func TestInitialize(t *testing.T) {
 			now := test.clock.Now()
 			test.fakeCAManager.currentJWTKeySlot = createSlot("jwt-a", now, tt.hasCurrent)
 			test.fakeCAManager.currentX509CASlot = createSlot("x509-a", now, tt.hasCurrent)
+			test.fakeCAManager.currentWITKeySlot = createSlot("wit-a", now, tt.hasCurrent)
 			test.fakeCAManager.nextJWTKeySlot = createSlot("jwt-b", now, tt.hasNext)
 			test.fakeCAManager.nextX509CASlot = createSlot("x509-b", now, tt.hasNext)
+			test.fakeCAManager.nextWITKeySlot = createSlot("wit-b", now, tt.hasNext)
 			test.fakeCAManager.prepareJWTKeyErr = tt.prepareJWTKeyErr
 			test.fakeCAManager.prepareX509CAErr = tt.prepareX509CAErr
+			test.fakeCAManager.prepareWITKeyErr = tt.prepareWITKeyErr
 
 			switch {
 			case tt.moveToPrepare:
@@ -155,15 +179,19 @@ func TestInitialize(t *testing.T) {
 
 			require.Equal(t, tt.expectCurrentJWTKeyID, test.fakeCAManager.currentJWTKeySlot.KmKeyID())
 			require.Equal(t, tt.expectCurrentX509CAID, test.fakeCAManager.currentX509CASlot.KmKeyID())
+			require.Equal(t, tt.expectCurrentWITKeyID, test.fakeCAManager.currentWITKeySlot.KmKeyID())
 			require.True(t, test.fakeCAManager.currentX509CASlot.isActive)
 			require.True(t, test.fakeCAManager.currentJWTKeySlot.isActive)
+			require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
 
 			if tt.moveToPrepare {
 				require.False(t, test.fakeCAManager.nextX509CASlot.IsEmpty())
 				require.False(t, test.fakeCAManager.nextJWTKeySlot.IsEmpty())
+				require.False(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
 			} else {
 				require.True(t, test.fakeCAManager.nextX509CASlot.IsEmpty())
 				require.True(t, test.fakeCAManager.nextJWTKeySlot.IsEmpty())
+				require.True(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
 			}
 		})
 	}
@@ -286,6 +314,59 @@ func TestRunX509CARotation(t *testing.T) {
 	require.True(t, test.fakeCAManager.nextX509CASlot.IsEmpty())
 }
 
+func TestRunWITKeyRotation(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Minute)
+	defer cancel()
+	test := setupTest(t)
+
+	go func() {
+		err := test.rotator.Run(ctx)
+		assert.NoError(t, err)
+	}()
+	test.clock.WaitForTickerMulti(time.Minute, 3, "waiting for the Run() ticker")
+
+	require.Equal(t, "wit-a", test.fakeCAManager.currentWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
+	// No next prepared
+	require.True(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
+
+	// Move to preparation mark nothing should change
+	test.clock.Add(time.Minute)
+
+	require.Equal(t, "wit-a", test.fakeCAManager.currentWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
+	require.Equal(t, "wit-b", test.fakeCAManager.nextWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
+
+	// Move after preparation mark
+	test.clock.Add(30 * time.Second)
+
+	test.fakeCAManager.waitWITKeyUpdate(ctx, t)
+
+	require.Equal(t, "wit-a", test.fakeCAManager.currentWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
+	require.Equal(t, "wit-b", test.fakeCAManager.nextWITKeySlot.keyID)
+	require.False(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
+
+	// Move to activation mark, nothing should change
+	test.clock.Add(30 * time.Second)
+
+	require.Equal(t, "wit-a", test.fakeCAManager.currentWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
+	require.Equal(t, "wit-b", test.fakeCAManager.nextWITKeySlot.keyID)
+	require.False(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
+
+	// Move after activation mark, next move to current
+	test.clock.Add(30 * time.Second)
+
+	test.fakeCAManager.waitWITKeyUpdate(ctx, t)
+
+	require.Equal(t, "wit-b", test.fakeCAManager.currentWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.currentWITKeySlot.isActive)
+	require.Equal(t, "wit-a", test.fakeCAManager.nextWITKeySlot.keyID)
+	require.True(t, test.fakeCAManager.nextWITKeySlot.IsEmpty())
+}
+
 func TestPruneBundle(t *testing.T) {
 	ctx, cancel := context.WithTimeout(context.Background(), time.Minute)
 	defer cancel()
@@ -361,6 +442,7 @@ func setupTest(tb testing.TB) *rotationTest {
 
 		x509CACh:          make(chan struct{}, 1),
 		jwtKeyCh:          make(chan struct{}, 1),
+		witKeyCh:          make(chan struct{}, 1),
 		pruneBundleCh:     make(chan struct{}, 1),
 		pruneCAJournalsCh: make(chan struct{}, 1),
 	}
@@ -369,8 +451,10 @@ func setupTest(tb testing.TB) *rotationTest {
 	now := clock.Now()
 	fManager.currentJWTKeySlot = createSlot("jwt-a", now, true)
 	fManager.currentX509CASlot = createSlot("x509-a", now, true)
+	fManager.currentWITKeySlot = createSlot("wit-a", now, true)
 	fManager.nextJWTKeySlot = createSlot("jwt-b", now, false)
 	fManager.nextX509CASlot = createSlot("x509-b", now, false)
+	fManager.nextWITKeySlot = createSlot("wit-b", now, false)
 
 	rotator := NewRotator(Config{
 		Manager:       fManager,
@@ -402,8 +486,13 @@ type fakeCAManager struct {
 	nextJWTKeySlot    *fakeSlot
 	prepareJWTKeyErr  error
 
+	currentWITKeySlot *fakeSlot
+	nextWITKeySlot    *fakeSlot
+	prepareWITKeyErr  error
+
 	x509CACh chan struct{}
 	jwtKeyCh chan struct{}
+	witKeyCh chan struct{}
 
 	pruneBundleWasCalled     bool
 	pruneBundleCh            chan struct{}
@@ -511,6 +600,49 @@ func (f *fakeCAManager) RotateJWTKey(context.Context) {
 	f.jwtKeyCh <- struct{}{}
 }
 
+func (f *fakeCAManager) GetCurrentWITKeySlot() manager.Slot {
+	return f.currentWITKeySlot
+}
+
+func (f *fakeCAManager) GetNextWITKeySlot() manager.Slot {
+	return f.nextWITKeySlot
+}
+
+func (f *fakeCAManager) PrepareWITKey(context.Context) error {
+	f.cleanWITKeyCh()
+	if f.prepareWITKeyErr != nil {
+		return f.prepareWITKeyErr
+	}
+
+	slot := f.nextWITKeySlot
+	if !f.currentWITKeySlot.hasValue {
+		slot = f.currentWITKeySlot
+	}
+
+	slot.hasValue = true
+	slot.preparationTime = f.clk.Now().Add(time.Minute)
+	slot.activationTime = f.clk.Now().Add(2 * time.Minute)
+	f.witKeyCh <- struct{}{}
+	return nil
+}
+
+func (f *fakeCAManager) ActivateWITKey(context.Context) {
+	f.cleanWITKeyCh()
+	f.currentWITKeySlot.isActive = true
+	f.witKeyCh <- struct{}{}
+}
+
+func (f *fakeCAManager) RotateWITKey(context.Context) {
+	f.cleanWITKeyCh()
+	currentID := f.currentWITKeySlot.keyID
+
+	f.currentWITKeySlot.keyID = f.nextWITKeySlot.keyID
+	f.currentWITKeySlot.isActive = true
+	f.nextWITKeySlot.keyID = currentID
+	f.nextWITKeySlot.hasValue = false
+	f.witKeyCh <- struct{}{}
+}
+
 func (f *fakeCAManager) SubscribeToLocalBundle(ctx context.Context) error {
 	return nil
 }
@@ -547,6 +679,13 @@ func (f *fakeCAManager) cleanJWTKeyCh() {
 	}
 }
 
+func (f *fakeCAManager) cleanWITKeyCh() {
+	select {
+	case <-f.witKeyCh:
+	default:
+	}
+}
+
 func (f *fakeCAManager) waitX509CAUpdate(ctx context.Context, t *testing.T) {
 	select {
 	case <-ctx.Done():
@@ -563,6 +702,14 @@ func (f *fakeCAManager) waitJWTKeyUpdate(ctx context.Context, t *testing.T) {
 	}
 }
 
+func (f *fakeCAManager) waitWITKeyUpdate(ctx context.Context, t *testing.T) {
+	select {
+	case <-ctx.Done():
+		assert.Fail(t, "context finished")
+	case <-f.witKeyCh:
+	}
+}
+
 func (f *fakeCAManager) waitPruneBundleCalled(ctx context.Context, t *testing.T) {
 	select {
 	case <-ctx.Done():
