@@ -3,6 +3,8 @@ package bundle
 import (
 	"net"
 	"time"
+
+	"github.com/spiffe/spire/pkg/common/diskcertmanager"
 )
 
 type EndpointConfig struct {
@@ -13,5 +15,7 @@ type EndpointConfig struct {
 	// If unset, the bundle endpoint will use SPIFFE auth.
 	ACME *ACMEConfig
 
-	RefreshHint *time.Duration
+	DiskCertManager *diskcertmanager.DiskCertManager
+
+	RefreshHint time.Duration
 }
