@@ -3,6 +3,8 @@ package endpoints
 import (
 	"sync"
 	"time"
+
+	"github.com/spiffe/spire/pkg/common/util"
 )
 
 type eventTracker struct {
@@ -20,7 +22,7 @@ func PollPeriods(pollTime time.Duration, trackTime time.Duration) uint {
 	if trackTime < time.Second {
 		trackTime = time.Second
 	}
-	return uint(1 + (trackTime-1)/pollTime)
+	return util.MustCast[uint](1 + (trackTime-1)/pollTime)
 }
 
 func NewEventTracker(pollPeriods uint) *eventTracker {
@@ -58,7 +60,7 @@ func (et *eventTracker) StopTracking(event uint) {
 
 func (et *eventTracker) SelectEvents() []uint {
 	pollList := *et.pool.Get().(*[]uint)
-	for event, _ := range et.events {
+	for event := range et.events {
 		if et.events[event] >= et.pollPeriods {
 			et.StopTracking(event)
 			continue
@@ -74,6 +76,6 @@ func (et *eventTracker) FreeEvents(events []uint) {
 	et.pool.Put(&events)
 }
 
-func (et *eventTracker) EventCount() uint {
-	return uint(len(et.events))
+func (et *eventTracker) EventCount() int {
+	return len(et.events)
 }
