@@ -14,6 +14,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/go-cmp/cmp"
+	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/hashicorp/hcl"
 	"github.com/spiffe/go-spiffe/v2/spiffeid"
 	identityproviderv1 "github.com/spiffe/spire-plugin-sdk/proto/spire/hostservice/server/identityprovider/v1"
@@ -258,7 +260,8 @@ kube_config_file_path = "/some/file/path"
 	require.EventuallyWithT(t, func(collect *assert.CollectT) {
 		actualWebhook, err := test.webhookClient.Get(context.Background(), webhook.Namespace, webhook.Name)
 		require.NoError(collect, err)
-		assert.Equal(collect, &admissionv1.MutatingWebhookConfiguration{
+
+		expected := &admissionv1.MutatingWebhookConfiguration{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:            webhook.Name,
 				ResourceVersion: "1",
@@ -270,7 +273,12 @@ kube_config_file_path = "/some/file/path"
 					},
 				},
 			},
-		}, actualWebhook)
+		}
+
+		// Ignore TypeMeta and ManagedFields which are populated by NewClientset's field management
+		assert.Empty(collect, cmp.Diff(expected, actualWebhook,
+			cmpopts.IgnoreFields(metav1.ObjectMeta{}, "ManagedFields"),
+			cmpopts.IgnoreFields(metav1.TypeMeta{}, "Kind", "APIVersion")))
 	}, testTimeout, testPollInterval)
 }
 
@@ -290,7 +298,8 @@ kube_config_file_path = "/some/file/path"
 	require.EventuallyWithT(t, func(collect *assert.CollectT) {
 		actualAPIService, err := test.apiServiceClient.Get(context.Background(), apiService.Namespace, apiService.Name)
 		require.NoError(collect, err)
-		assert.Equal(collect, &apiregistrationv1.APIService{
+
+		expected := &apiregistrationv1.APIService{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:            apiService.Name,
 				ResourceVersion: "1",
@@ -298,7 +307,12 @@ kube_config_file_path = "/some/file/path"
 			Spec: apiregistrationv1.APIServiceSpec{
 				CABundle: []byte(testBundleData),
 			},
-		}, actualAPIService)
+		}
+
+		// Ignore TypeMeta and ManagedFields which are populated by NewClientset's field management
+		assert.Empty(collect, cmp.Diff(expected, actualAPIService,
+			cmpopts.IgnoreFields(metav1.ObjectMeta{}, "ManagedFields"),
+			cmpopts.IgnoreFields(metav1.TypeMeta{}, "Kind", "APIVersion")))
 	}, testTimeout, testPollInterval)
 }
 
@@ -847,7 +861,7 @@ type fakeWebhookClient struct {
 }
 
 func newFakeWebhookClient(config *Configuration) *fakeWebhookClient {
-	client := fake.NewSimpleClientset()
+	client := fake.NewClientset()
 	w := &fakeWebhookClient{
 		mutatingWebhookClient: mutatingWebhookClient{
 			Interface:    client,
@@ -903,7 +917,9 @@ type fakeAPIServiceClient struct {
 }
 
 func newFakeAPIServiceClient(config *Configuration) *fakeAPIServiceClient {
-	client := fakeaggregator.NewSimpleClientset()
+	// NewSimpleClientset is deprecated, but the aggregator package doesn't provide
+	// NewClientset yet (only available when apply configurations are generated).
+	client := fakeaggregator.NewSimpleClientset() //nolint:staticcheck // https://github.com/spiffe/spire/issues/6530: NewSimpleClientset is deprecated, but no alternative exists for aggregator.
 	a := &fakeAPIServiceClient{
 		apiServiceClient: apiServiceClient{
 			Interface:       client,
