@@ -1,7 +1,6 @@
 package fixture
 
 import (
-	"os"
 	"path/filepath"
 	"runtime"
 )
@@ -29,7 +28,3 @@ func Path(path string) string {
 func Join(parts ...string) string {
 	return Path(filepath.Join(parts...))
 }
-
-func Load(path string) ([]byte, error) {
-	return os.ReadFile(Path(path))
-}
