@@ -3,6 +3,7 @@
 package spiretest
 
 import (
+	"errors"
 	"net"
 	"path/filepath"
 	"testing"
@@ -23,3 +24,19 @@ func StartGRPCServer(t *testing.T, registerFn func(s *grpc.Server)) net.Addr {
 	socketPath := filepath.Join(dir, "server.sock")
 	return StartGRPCUDSSocketServer(t, socketPath, registerFn)
 }
+
+func ServeGRPCServerOnListener(t *testing.T, server *grpc.Server, listener net.Listener) {
+	errCh := make(chan error, 1)
+	go func() {
+		errCh <- server.Serve(listener)
+	}()
+	t.Cleanup(func() {
+		server.Stop()
+		err := <-errCh
+		switch {
+		case err == nil, errors.Is(err, grpc.ErrServerStopped):
+		default:
+			t.Fatal(err)
+		}
+	})
+}
